from setuptools import setup

setup(
    name='promptdb',
    version='0.0.1',
    description='',
    long_description='',
    url='https://promptdb.io',
    author='denis.bilenko',
    author_email='denis.bilenko@gmail.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
